@@ -1,6 +1,13 @@
 import pytest
 
 from rapidfuzz import fuzz, process_cpp, process_py
+from rapidfuzz.distance import Levenshtein
+from rapidfuzz.distance import Levenshtein_py
+
+try:
+    import numpy as np
+except:
+    pass
 
 
 def wrapped(func):
@@ -44,7 +51,7 @@ class process:
         assert res1.dtype == res2.dtype
         assert res1.shape == res2.shape
         if res1.size and res2.size:
-            assert res1 == res2
+            assert np.array_equal(res1, res2)
         return res1
 
 
@@ -382,3 +389,37 @@ def test_wrapped_function(scorer):
     assert process.cdist(["test"], [float("nan")], scorer=scorer)[0, 0] == 100
     assert process.cdist(["test"], [None], scorer=scorer)[0, 0] == 100
     assert process.cdist(["test"], ["tes"], scorer=scorer)[0, 0] == 100
+
+
+def test_cdist_not_symmetric():
+    pytest.importorskip("numpy")
+    strings = ["test", "test2"]
+    expected_res = np.array([[0, 1], [2, 0]])
+    assert np.array_equal(
+        process.cdist(strings, strings, scorer=Levenshtein.distance, weights=(1, 2, 1)),
+        expected_res,
+    )
+
+
+def test_cdist_pure_python_dtype():
+    pytest.importorskip("numpy")
+    assert (
+        process.cdist(["test"], ["test"], scorer=Levenshtein_py.distance).dtype
+        == np.int32
+    )
+    assert (
+        process.cdist(["test"], ["test"], scorer=Levenshtein_py.similarity).dtype
+        == np.int32
+    )
+    assert (
+        process.cdist(
+            ["test"], ["test"], scorer=Levenshtein_py.normalized_distance
+        ).dtype
+        == np.float32
+    )
+    assert (
+        process.cdist(
+            ["test"], ["test"], scorer=Levenshtein_py.normalized_similarity
+        ).dtype
+        == np.float32
+    )
